# -*- coding: utf-8 -*-
from __future__ import unicode_literals

"""
List of reserved usernames (pre-defined list of special banned and reserved keywords in names,
such as "root", "www", "admin"). Useful when creating public systems, where users can choose
a login name or a sub-domain name.
__References:__
1. http://www.bannedwordlist.com/
2. http://blog.postbit.com/reserved-username-list.html
3. https://ldpreload.com/blog/names-to-reserve
"""

_d = """
about
abuse
access
account
accounts
add
address
adm
admin
administration
administrator
ads
adult
advertising
affiliate
affiliates
ajax
anal
analytics
android
anon
anonymous
anus
apache
api
app
apps
archive
arse
ass
atom
audio
auth
authentication
authority
autoconfig
avatar
backup
balls
ballsack
banner
banners
bastard
biatch
billing
bin
bitch
blog
blogs
bloody
blowjob
board
bollock
bollok
boner
boob
bot
bots
broadcasthost
bugger
bum
business
butt
buttplug
ca
cache
cadastro
calendar
campaign
careers
ceo
cert
cgi
chat
client
cliente
clitoris
cock
code
comercial
commerce
compare
compras
config
connect
console
contact
contest
coon
copyright
crap
create
crt
css
cunt
daemon
damn
dashboard
data
db
delete
demo
design
designer
dev
devel
devs
dick
dildo
dir
directory
dns
doc
docs
domain
download
downloads
dyke
ecommerce
edit
editor
email
end
errors
events
example
fag
faq
faqs
favorite
feck
feed
feedback
felching
fellate
fellatio
file
files
firewall
flange
flog
follow
forum
forums
free
ftp
fuck
fucker
fudge
fudgepacker
gadget
gadgets
games
god
goddamn
group
groups
guarantee
guest
guests
hell
help
home
homepage
homo
host
hosting
hostmaster
hostname
hpg
hr
html
http
httpd
https
image
images
imap
img
index
indice
info
information
inquiry
intranet
intro
introduction
invite
invoice
invoices
ipad
iphone
irc
is
isatap
it
java
javascript
jerk
jizz
job
jobs
js
knob
knobend
knowledgebase
labia
licence
license
licensing
links
list
list-request
lists
live
lmao
lmfao
localdomain
localhost
log
login
logout
logs
magazine
mail
mail1
mail2
mail3
mail4
mail5
mailer
mailer-daemon
mailing
maintainer
manager
marketing
master
me
media
message
messenger
microblog
microblogs
mine
mis
mob
mobile
mod
moderator
moderators
mods
motherfucker
movie
movies
mp3
msg
msn
muff
music
musicas
mx
my
mysql
name
named
net
network
new
news
newsletter
nginx
nick
nickname
nigga
nigger
no-reply
nobody
noc
noreply
notes
noticias
ns
ns1
ns2
ns3
ns4
ntp
null
old
omg
online
operator
operators
order
orders
packer
page
pager
pages
panel
passwd
password
pay
payment
payments
penis
perl
photo
photoalbum
photos
php
pic
pics
piss
plugin
plugins
policies
policy
poop
pop
pop3
post
postfix
postmaster
posts
pr
pricing
prick
printer
privacy
profile
project
projects
promo
promotion
proxy
pub
pube
public
purchase
pussy
python
queer
random
redir
refund
refunds
register
registration
return
returns
reviews
root
rss
ruby
sale
sales
sample
samples
script
scripts
scrotum
search
secure
security
send
sendmail
service
services
setting
settings
setup
sex
sh1t
shit
shop
signin
signup
site
sitemap
sites
slut
smegma
smtp
soporte
spunk
sql
squid
ssh
ssl
ssladmin
ssladministrator
sslwebmaster
stage
staging
start
stat
static
stats
status
store
stores
stream
subdomain
subscribe
sudo
superuser
suporte
support
survey
sync
sys
sysadmin
syslog
sysop
system
tablet
tablets
talk
task
tasks
tech
telnet
terminal
terms
test
test1
test2
test3
teste
testimonials
tests
theme
themes
tit
tmp
todo
tools
tosser
tour
turd
tv
twat
update
upload
url
usage
usenet
user
userdb
username
users
usuario
uucp
vagina
vendas
video
videos
visitor
wank
web
webmail
webmaster
website
websites
wheel
whore
win
workshop
wpad
wtf
ww
wws
www
www1
www2
www3
www4
www5
www6
www7
wwws
wwww
xpg
xxx
you
yourdomain
yourname
yoursite
yourusername
"""



def get_reserved_wordlist():
    return set(_d.splitlines())


__all__ = ["get_reserved_wordlist"]
